@@ -7,44 +7,44 @@ use core::sync::atomic::{AtomicBool, Ordering::Relaxed};
 use interrupt::CriticalSection;
 use util::*;
 
-pub struct Peek<'a, T>(&'a Cell<T>);
-impl<'a, T> Peek<'a, T> {
-    pub fn peek_num(&self) -> Result<usize, MemoryState> {
-        self.0.peek_num()
+pub struct Ref<'a, T>(&'a Cell<T>);
+impl<'a, T> Ref<'a, T> {
+    pub fn ref_num(&self) -> Result<usize, MemoryState> {
+        self.0.ref_num()
     }
     pub fn remove(self) {
         self.0.will_drop.store(true, Relaxed);
     }
 }
-impl<'a, T> Deref for Peek<'a, T> {
+impl<'a, T> Deref for Ref<'a, T> {
     type Target = T;
     fn deref(&self) -> &Self::Target {
         unsafe { self.0.val.assume_init_ref() }
     }
 }
-impl<'a, T: fmt::Debug> fmt::Debug for Peek<'a, T> {
+impl<'a, T: fmt::Debug> fmt::Debug for Ref<'a, T> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         fmt::Debug::fmt(&self, f)
     }
 }
-impl<'a, T> Drop for Peek<'a, T> {
+impl<'a, T> Drop for Ref<'a, T> {
     fn drop(&mut self) {
         let _cs = CriticalSection::new();
         let will_drop = self.0.will_drop.load(Relaxed);
         let old = self.0.state.fetch_update(Relaxed, Relaxed, |mut x| {
-            if x == MemoryPeek::PEEK1 {
+            if x == MemoryRefer::REF1 {
                 if will_drop {
                     return Some(MemoryState::Erasing.into());
                 }
             }
-            if x.peek_sub().is_ok() {
+            if x.ref_sub().is_ok() {
                 Some(x)
             } else {
                 None
             }
         });
         match old {
-            Ok(MemoryPeek::PEEK1) => {
+            Ok(MemoryRefer::REF1) => {
                 if will_drop {
                     unsafe { ptr::drop_in_place(self.0.val.as_ptr() as *mut T) };
                     self.0.will_drop.store(false, Relaxed);
@@ -60,21 +60,21 @@ impl<'a, T> Drop for Peek<'a, T> {
 
 pub struct Cell<T> {
     val: MaybeUninit<T>,
-    state: AtomicMemoryPeek,
+    state: AtomicMemoryRefer,
     will_drop: AtomicBool,
 }
 impl<T> Cell<T> {
     pub const fn new() -> Self {
         Cell {
             val: MaybeUninit::uninit(),
-            state: AtomicMemoryPeek::ZERO,
+            state: AtomicMemoryRefer::ZERO,
             will_drop: AtomicBool::new(false),
         }
     }
     pub fn new_with(init: T) -> Self {
         Cell {
             val: MaybeUninit::new(init),
-            state: AtomicMemoryPeek::new(MemoryState::Initialized.into()),
+            state: AtomicMemoryRefer::new(MemoryState::Initialized.into()),
             will_drop: AtomicBool::new(false),
         }
     }
@@ -83,15 +83,15 @@ impl<T> Cell<T> {
     }
     pub fn is_initialized(&self) -> bool {
         let state = self.state.load(Relaxed);
-        state.is_peekable()
+        state.can_refer()
     }
-    pub fn peek_num(&self) -> Result<usize, MemoryState> {
-        self.state.load(Relaxed).peek_num()
+    pub fn ref_num(&self) -> Result<usize, MemoryState> {
+        self.state.load(Relaxed).ref_num()
     }
     pub fn try_take(&self) -> Result<T, Error<()>> {
         let _cs = CriticalSection::new();
         if let Err(state) = self.state.fetch_update(Relaxed, Relaxed, |x| {
-            if x.peek_num() == Ok(0) {
+            if x.ref_num() == Ok(0) {
                 Some(MemoryState::Erasing.into())
             } else {
                 None
@@ -123,7 +123,7 @@ impl<T> Cell<T> {
             }
         }
     }
-    pub fn try_get(&self) -> Result<Peek<T>, Error<()>> {
+    pub fn try_get(&self) -> Result<Ref<T>, Error<()>> {
         if self.will_drop.load(Relaxed) {
             return Err(Error {
                 state: MemoryState::Erasing,
@@ -132,7 +132,7 @@ impl<T> Cell<T> {
             });
         }
         if let Err(state) = self.state.fetch_update(Relaxed, Relaxed, |mut x| {
-            if x.peek_add().is_ok() {
+            if x.ref_add().is_ok() {
                 Some(x)
             } else {
                 None
@@ -145,11 +145,11 @@ impl<T> Cell<T> {
                 retry: state.is_transient(),
             })
         } else {
-            Ok(Peek(self))
+            Ok(Ref(self))
         }
     }
     /// Notice: `Spin`
-    pub fn get(&self) -> Option<Peek<T>> {
+    pub fn get(&self) -> Option<Ref<T>> {
         loop {
             match self.try_get() {
                 Ok(val) => return Some(val),
@@ -200,7 +200,7 @@ impl<T> Cell<T> {
         match self.state.fetch_update(Relaxed, Relaxed, |x| {
             if x.state().is_uninitialized() {
                 Some(MemoryState::Initializing.into())
-            } else if x.peek_num() == Ok(0) {
+            } else if x.ref_num() == Ok(0) {
                 Some(MemoryState::Erasing.into())
             } else {
                 None
@@ -241,7 +241,7 @@ impl<T> Cell<T> {
             }
         }
     }
-    pub fn get_or_try_init(&self, value: T) -> Result<Peek<T>, Error<T>> {
+    pub fn get_or_try_init(&self, value: T) -> Result<Ref<T>, Error<T>> {
         let _cs = CriticalSection::new();
         if let Err(_) = self.state.compare_exchange(
             MemoryState::Uninitialized.into(),
@@ -262,12 +262,12 @@ impl<T> Cell<T> {
             )
         } else {
             unsafe { ptr::write(self.ptr(), value) };
-            self.state.store(MemoryPeek::PEEK1, Relaxed);
-            Ok(Peek(self))
+            self.state.store(MemoryRefer::REF1, Relaxed);
+            Ok(Ref(self))
         }
     }
     /// Notice: `Spin`
-    pub fn get_or_init(&self, mut value: T) -> Peek<T> {
+    pub fn get_or_init(&self, mut value: T) -> Ref<T> {
         loop {
             match self.get_or_try_init(value) {
                 Ok(val) => return val,
