@@ -11,14 +11,14 @@ fn base() {
     assert!(!CELL.is_initialized());
     assert!(CELL.take().is_none());
 
-    assert!(CELL.peek_num().is_err());
+    assert!(CELL.ref_num().is_err());
     assert!(CELL.set(3).is_ok());
-    assert_eq!(CELL.peek_num(), Ok(0));
-    let peek = CELL.get().unwrap();
-    assert_eq!(CELL.peek_num(), Ok(1));
-    assert_eq!(*peek, 3);
+    assert_eq!(CELL.ref_num(), Ok(0));
+    let refer = CELL.get().unwrap();
+    assert_eq!(CELL.ref_num(), Ok(1));
+    assert_eq!(*refer, 3);
     assert!(CELL.take().is_none());
-    drop(peek);
+    drop(refer);
     assert_eq!(CELL.take().unwrap(), 3);
 
     assert!(CELL.set(4).is_ok());
@@ -27,9 +27,9 @@ fn base() {
 
     assert_eq!(CELL.swap(5), Ok(None));
     assert_eq!(CELL.swap(6), Ok(Some(5)));
-    let peek = CELL.get();
+    let refer = CELL.get();
     assert_eq!(CELL.swap(7), Err(7));
-    drop(peek);
+    drop(refer);
     assert_eq!(CELL.swap(8), Ok(Some(6)));
     assert_eq!(CELL.take().unwrap(), 8);
 }
